pub fn parse_executable(
s: &str,
) -> Result<LanguageExpression<'_>, LambdaParseError>Expand description
A function which maps strings to language of thought expressions. Crucially, it automatically performs all lambda reductions.
Errors
Will panic if the expression is malformed, or if not all lambda terms can be reduced.